==> haskell-monad-journal-0.8.1-348-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-5zQRdNSJLOd3Py9mu9yW9s
key:                  monad-journal-0.8.1-5zQRdNSJLOd3Py9mu9yW9s
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  65595a69905a34a63c0a8fc78bed9d1a
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-journal
hs-libraries:         HSmonad-journal-0.8.1-5zQRdNSJLOd3Py9mu9yW9s
depends:
    base-4.17.2.1 monad-control-1.0.3.1-EMymL5qvPF86Ly30QNsrD5
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-C48guHuMOb9AOa55HXY0p9

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.1-349-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-HBfL6lffU3Bvdb5L8BWHy
key:                  monad-journal-0.8.1-HBfL6lffU3Bvdb5L8BWHy
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  5cee5d6869fd881dc5808c6369982344
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-journal
hs-libraries:         HSmonad-journal-0.8.1-HBfL6lffU3Bvdb5L8BWHy
depends:
    base-4.17.2.1 monad-control-1.0.3.1-69dnLrrVpTh4jQgsdou34S
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-GqnHbqWDT0e8qlqX7fWzwX

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
